@@ -1,5 +1,5 @@
 package Net::Checkpoint::Management::v1;
-$Net::Checkpoint::Management::v1::VERSION = '0.001004';
+$Net::Checkpoint::Management::v1::VERSION = '0.001005';
 # ABSTRACT: Checkpoint Management API version 1.x client library
 
 use 5.024;
@@ -42,13 +42,33 @@ has 'api_version' => (
 with 'Net::Checkpoint::Management::v1::Role::REST::Client';
 
 sub _error_handler ($self, $data) {
-    my $error_message = (
-        exists $data->{'blocking-errors'}
+    my $error_message;
+
+    if (exists $data->{'blocking-errors'}
         && ref $data->{'blocking-errors'} eq 'ARRAY'
         && exists $data->{'blocking-errors'}->[0]
-        && exists $data->{'blocking-errors'}->[0]->{message})
-        ? $data->{'blocking-errors'}->[0]->{message}
-        : $data->{message};
+        && exists $data->{'blocking-errors'}->[0]->{message}) {
+        $error_message = $data->{'blocking-errors'}->[0]->{message};
+    }
+    elsif (exists $data->{errors}
+        && ref $data->{errors} eq 'ARRAY'
+        && exists $data->{errors}->[0]
+        && exists $data->{errors}->[0]->{message}) {
+        $error_message = $data->{errors}->[0]->{message};
+    }
+    # when ignore-warnings isn't passed to the API call, a response with only
+    # warnings is also considered an error because its changes aren't saved
+    # when passing ignore-warnings the error handler isn't called because the
+    # http response code is 200
+    elsif (exists $data->{warnings}
+        && ref $data->{warnings} eq 'ARRAY'
+        && exists $data->{warnings}->[0]
+        && exists $data->{warnings}->[0]->{message}) {
+        $error_message = $data->{warnings}->[0]->{message};
+    }
+    else {
+        $error_message = $data->{message};
+    }
     croak($error_message);
 }
 
@@ -269,6 +289,13 @@ Net::Checkpoint::Management::v1::Role::ObjectMethods->apply([
         update   => 'set-session',
         list_key => 'objects',
     },
+    {
+        object   => 'tasks',
+        singular => 'task',
+        list     => 'show-tasks',
+        get      => 'show-task',
+        list_key => 'tasks',
+    },
 ]);
 
 
@@ -333,7 +360,7 @@ Net::Checkpoint::Management::v1 - Checkpoint Management API version 1.x client l
 
 =head1 VERSION
 
-version 0.001004
+version 0.001005
 
 =head1 SYNOPSIS
 
